@@ -7,18 +7,18 @@
 
 #include <vdr/menu.h>
 #include <vdr/remote.h>
-#include <vdr/menu.h>
+#include <vdr/player.h>
 #include "femoncfg.h"
 #include "femonreceiver.h"
 #include "femonosd.h"
 #include "femonservice.h"
 #include "femontools.h"
 
-#if defined(APIVERSNUM) && APIVERSNUM < 10600
-#error "VDR-1.6.0 API version or greater is required!"
+#if defined(APIVERSNUM) && APIVERSNUM < 10716
+#error "VDR-1.7.16 API version or greater is required!"
 #endif
 
-static const char VERSION[]       = "1.6.7";
+static const char VERSION[]       = "1.7.9";
 static const char DESCRIPTION[]   = trNOOP("DVB Signal Information Monitor (OSD)");
 static const char MAINMENUENTRY[] = trNOOP("Signal Information");
 
@@ -50,13 +50,13 @@ cPluginFemon::cPluginFemon()
   // Initialize any member variables here.
   // DON'T DO ANYTHING ELSE THAT MAY HAVE SIDE EFFECTS, REQUIRE GLOBAL
   // VDR OBJECTS TO EXIST OR PRODUCE ANY OUTPUT!
-  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  debug("%s()\n", __PRETTY_FUNCTION__);
 }
 
 cPluginFemon::~cPluginFemon()
 {
   // Clean up after yourself!
-  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  debug("%s()\n", __PRETTY_FUNCTION__);
 }
 
 const char *cPluginFemon::CommandLineHelp(void)
@@ -96,8 +96,8 @@ void cPluginFemon::Housekeeping(void)
 cOsdObject *cPluginFemon::MainMenuAction(void)
 {
   // Perform the action when selected from the main VDR menu.
-  Dprintf("%s()\n", __PRETTY_FUNCTION__);
-  if (cReplayControl::NowReplaying() || (Channels.Count() <= 0))
+  debug("%s()\n", __PRETTY_FUNCTION__);
+  if (cControl::Control() || (Channels.Count() <= 0))
      Skins.Message(mtInfo, tr("Femon not available"));
   else
      return cFemonOsd::Instance(true);
@@ -110,10 +110,9 @@ bool cPluginFemon::SetupParse(const char *Name, const char *Value)
   if      (!strcasecmp(Name, "HideMenu"))       femonConfig.hidemenu       = atoi(Value);
   else if (!strcasecmp(Name, "DisplayMode"))    femonConfig.displaymode    = atoi(Value);
   else if (!strcasecmp(Name, "Position"))       femonConfig.position       = atoi(Value);
-  else if (!strcasecmp(Name, "OSDHeight"))      femonConfig.osdheight      = atoi(Value);
-  else if (!strcasecmp(Name, "OSDOffset"))      femonConfig.osdoffset      = atoi(Value);
   else if (!strcasecmp(Name, "Skin"))           femonConfig.skin           = atoi(Value);
   else if (!strcasecmp(Name, "Theme"))          femonConfig.theme          = atoi(Value);
+  else if (!strcasecmp(Name, "Downscale"))      femonConfig.downscale      = atoi(Value);
   else if (!strcasecmp(Name, "RedLimit"))       femonConfig.redlimit       = atoi(Value);
   else if (!strcasecmp(Name, "GreenLimit"))     femonConfig.greenlimit     = atoi(Value);
   else if (!strcasecmp(Name, "UpdateInterval")) femonConfig.updateinterval = atoi(Value);
@@ -134,6 +133,8 @@ bool cPluginFemon::Service(const char *Id, void *Data)
   if (strcmp(Id,"FemonService-v1.0") == 0) {
      if (Data) {
         FemonService_v1_0 *data = (FemonService_v1_0*)Data;
+        if (!cDevice::ActualDevice())
+           return false; 
         int ndx = cDevice::ActualDevice()->CardIndex();
         data->fe_name = getFrontendName(ndx);
         data->fe_status = getFrontendStatus(ndx);
@@ -195,7 +196,7 @@ cString cPluginFemon::SVDRPCommand(const char *Command, const char *Option, int
         return cString("Cannot open femon plugin while replaying");
         }
      if (!cFemonOsd::Instance())
-        cRemote::CallPlugin("femon");
+        cRemote::CallPlugin(Name());
      return cString("Opening femon plugin");
      }
   else if (strcasecmp(Command, "QUIT") == 0) {
@@ -276,7 +277,7 @@ public:
 
 cMenuFemonSetup::cMenuFemonSetup(void)
 {
-  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  debug("%s()\n", __PRETTY_FUNCTION__);
   dispmodes[eFemonModeBasic]       = tr("basic");
   dispmodes[eFemonModeTransponder] = tr("transponder");
   dispmodes[eFemonModeStream]      = tr("stream");
@@ -321,11 +322,8 @@ void cMenuFemonSetup::Setup(void)
   Add(new cMenuEditBoolItem(tr("Position"), &data.position, trVDR("bottom"), trVDR("top")));
   help.Append(tr("Define the position of OSD."));
 
-  Add(new cMenuEditIntItem(trVDR("Setup.OSD$Height"), &data.osdheight, 400, 500));
-  help.Append(tr("Define the height of OSD."));
-
-  Add(new cMenuEditIntItem(tr("Horizontal offset"), &data.osdoffset, -50, 50));
-  help.Append(tr("Define the horizontal offset of OSD."));
+  Add(new cMenuEditIntItem(tr("Downscale OSD size [%]"), &data.downscale, 0, 20));
+  help.Append(tr("Define the downscale ratio for OSD size."));
 
   Add(new cMenuEditIntItem(tr("Red limit [%]"), &data.redlimit, 1, 50));
   help.Append(tr("Define a limit for red bar, which is used to indicate a bad signal."));
@@ -361,15 +359,14 @@ void cMenuFemonSetup::Setup(void)
 
 void cMenuFemonSetup::Store(void)
 {
-  Dprintf("%s()\n", __PRETTY_FUNCTION__);
+  debug("%s()\n", __PRETTY_FUNCTION__);
   femonConfig = data;
   SetupStore("HideMenu",       femonConfig.hidemenu);
   SetupStore("DisplayMode",    femonConfig.displaymode);
   SetupStore("Skin",           femonConfig.skin);
   SetupStore("Theme",          femonConfig.theme);
   SetupStore("Position",       femonConfig.position);
-  SetupStore("OSDHeight",      femonConfig.osdheight);
-  SetupStore("OSDOffset",      femonConfig.osdoffset);
+  SetupStore("Downscale",      femonConfig.downscale);
   SetupStore("RedLimit",       femonConfig.redlimit);
   SetupStore("GreenLimit",     femonConfig.greenlimit);
   SetupStore("UpdateInterval", femonConfig.updateinterval);
