@@ -34,15 +34,24 @@ private:
   double            m_SvdrpAudioBitrate;
   SvdrpConnection_v1_0 m_SvdrpConnection;
   cPlugin          *m_SvdrpPlugin;
-  dvb_frontend_info m_FrontendInfo;
   int               m_Number;
   int               m_OldNumber;
   uint16_t          m_SNR;
+  bool              m_SNRValid;
   uint16_t          m_Signal;
+  bool              m_SignalValid;
   uint32_t          m_BER;
+  bool              m_BERValid;
   uint32_t          m_UNC;
+  bool              m_UNCValid;
   fe_status_t       m_FrontendStatus;
+  bool              m_FrontendStatusValid;
+  dvb_frontend_info m_FrontendInfo;
   int               m_DisplayMode;
+  int               m_OsdWidth;
+  int               m_OsdHeight;
+  int               m_OsdLeft;
+  int               m_OsdTop;
   cFont            *m_Font;
   cTimeMs           m_InputTime;
   cCondWait         m_Sleep;
