@@ -41,6 +41,11 @@ enum eSymbols {
   SYMBOL_FIVE,
   SYMBOL_SIX,
   SYMBOL_SEVEN,
+  SYMBOL_EIGHT,
+  SYMBOL_FORMAT_1080,
+  SYMBOL_FORMAT_720,
+  SYMBOL_FORMAT_576,
+  SYMBOL_FORMAT_480,
   SYMBOL_MAX_COUNT
   };
 
